==> camunda-engine-7.12.0-sources.jar: org/camunda/bpm/engine/impl/pvm/runtime/operation/PvmAtomicOperationActivityStartCreateScope.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.pvm.runtime.operation;

import org.camunda.bpm.engine.impl.pvm.PvmActivity;
import org.camunda.bpm.engine.impl.pvm.runtime.PvmExecutionImpl;

/**
 * @author Thorben Lindhauer
 *
 */
public class PvmAtomicOperationActivityStartCreateScope extends PvmAtomicOperationCreateScope {

  public boolean isAsync(PvmExecutionImpl execution) {
    PvmActivity activity = execution.getActivity();
    return activity.isAsyncBefore()
        && !execution.hasProcessInstanceStartContext();
  }

  public boolean isAsyncCapable() {
    return true;
  }

  public String getCanonicalName() {
    return "activity-start-create-scope";
  }

  protected void scopeCreated(PvmExecutionImpl execution) {
    execution.performOperation(ACTIVITY_START);
  }
}

==> camunda-engine-7.17.0-sources.jar: org/camunda/bpm/engine/impl/pvm/runtime/operation/PvmAtomicOperationActivityStartCreateScope.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.pvm.runtime.operation;

import org.camunda.bpm.engine.impl.pvm.PvmActivity;
import org.camunda.bpm.engine.impl.pvm.runtime.PvmExecutionImpl;

/**
 * @author Thorben Lindhauer
 *
 */
public class PvmAtomicOperationActivityStartCreateScope extends PvmAtomicOperationCreateScope {

  public boolean isAsync(PvmExecutionImpl execution) {
    PvmActivity activity = execution.getActivity();
    return activity.isAsyncBefore();
  }

  public boolean isAsyncCapable() {
    return true;
  }

  public String getCanonicalName() {
    return "activity-start-create-scope";
  }

  protected void scopeCreated(PvmExecutionImpl execution) {
    execution.setIgnoreAsync(false);
    execution.performOperation(ACTIVITY_START);
  }
}
